from time import sleep


def main(_input_consumed, _results_consumed, results_provided):
    """
    car price
    """
    # sleep(0.5)
    results_provided["car_price"] = sum(_results_consumed["prices"])
